@@ -21,8 +21,8 @@ function initialize!(integrator, cache::Vern6ConstantCache)
 end
 
 @muladd function perform_step!(integrator, cache::Vern6ConstantCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack c1, c2, c3, c4, c5, c6, a21, a31, a32, a41, a43, a51, a53, a54, a61, a63, a64, a65, a71, a73, a74, a75, a76, a81, a83, a84, a85, a86, a87, a91, a94, a95, a96, a97, a98, btilde1, btilde4, btilde5, btilde6, btilde7, btilde8, btilde9 = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; c1, c2, c3, c4, c5, c6, a21, a31, a32, a41, a43, a51, a53, a54, a61, a63, a64, a65, a71, a73, a74, a75, a76, a81, a83, a84, a85, a86, a87, a91, a94, a95, a96, a97, a98, btilde1, btilde4, btilde5, btilde6, btilde7, btilde8, btilde9) = cache.tab
     k1 = integrator.fsalfirst
     a = dt * a21
     k2 = f(uprev + a * k1, p, t + c1 * dt)
@@ -65,7 +65,7 @@ end
     if !cache.lazy && (integrator.opts.adaptive == false ||
         accept_step_controller(integrator, integrator.opts.controller))
         k = integrator.k
-        @unpack c10, a1001, a1004, a1005, a1006, a1007, a1008, a1009, c11, a1101, a1104, a1105, a1106, a1107, a1108, a1109, a1110, c12, a1201, a1204, a1205, a1206, a1207, a1208, a1209, a1210, a1211 = cache.tab.extra
+        (; c10, a1001, a1004, a1005, a1006, a1007, a1008, a1009, c11, a1101, a1104, a1105, a1106, a1107, a1108, a1109, a1110, c12, a1201, a1204, a1205, a1206, a1207, a1208, a1209, a1210, a1211) = cache.tab.extra
         k[10] = f(
             uprev +
             dt * (a1001 * k[1] + a1004 * k[4] + a1005 * k[5] + a1006 * k[6] +
@@ -94,7 +94,7 @@ end
 function initialize!(integrator, cache::Vern6Cache)
     alg = unwrap_alg(integrator, false)
     cache.lazy ? (integrator.kshortsize = 9) : (integrator.kshortsize = 12)
-    @unpack k = integrator
+    (; k) = integrator
     resize!(k, integrator.kshortsize)
     k[1] = cache.k1
     k[2] = cache.k2
@@ -117,10 +117,10 @@ function initialize!(integrator, cache::Vern6Cache)
 end
 
 @muladd function perform_step!(integrator, cache::Vern6Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     uidx = eachindex(integrator.uprev)
-    @unpack c1, c2, c3, c4, c5, c6, a21, a31, a32, a41, a43, a51, a53, a54, a61, a63, a64, a65, a71, a73, a74, a75, a76, a81, a83, a84, a85, a86, a87, a91, a94, a95, a96, a97, a98, btilde1, btilde4, btilde5, btilde6, btilde7, btilde8, btilde9 = cache.tab
-    @unpack k1, k2, k3, k4, k5, k6, k7, k8, k9, utilde, tmp, rtmp, atmp, stage_limiter!, step_limiter!, thread = cache
+    (; c1, c2, c3, c4, c5, c6, a21, a31, a32, a41, a43, a51, a53, a54, a61, a63, a64, a65, a71, a73, a74, a75, a76, a81, a83, a84, a85, a86, a87, a91, a94, a95, a96, a97, a98, btilde1, btilde4, btilde5, btilde6, btilde7, btilde8, btilde9) = cache.tab
+    (; k1, k2, k3, k4, k5, k6, k7, k8, k9, utilde, tmp, rtmp, atmp, stage_limiter!, step_limiter!, thread) = cache
     a = dt * a21
     @.. broadcast=false thread=thread tmp=uprev + a * k1
     stage_limiter!(tmp, integrator, p, t + c1 * dt)
@@ -179,8 +179,8 @@ end
     if !cache.lazy && (integrator.opts.adaptive == false ||
         accept_step_controller(integrator, integrator.opts.controller))
         k = integrator.k
-        @unpack c10, a1001, a1004, a1005, a1006, a1007, a1008, a1009, c11, a1101, a1104, a1105, a1106, a1107, a1108, a1109, a1110, c12, a1201, a1204, a1205, a1206, a1207, a1208, a1209, a1210, a1211 = cache.tab.extra
-        @unpack tmp = cache
+        (; c10, a1001, a1004, a1005, a1006, a1007, a1008, a1009, c11, a1101, a1104, a1105, a1106, a1107, a1108, a1109, a1110, c12, a1201, a1204, a1205, a1206, a1207, a1208, a1209, a1210, a1211) = cache.tab.extra
+        (; tmp) = cache
         @.. broadcast=false thread=thread tmp=uprev +
                                               dt *
                                               (a1001 * k[1] + a1004 * k[4] + a1005 * k[5] +
@@ -218,7 +218,7 @@ function initialize!(integrator, cache::Vern7ConstantCache)
 end
 
 @muladd function perform_step!(integrator, cache::Vern7ConstantCache, repeat_step = false)
-    @unpack t, dt, uprev, u, k, f, p = integrator
+    (; t, dt, uprev, u, k, f, p) = integrator
     T = constvalue(recursive_unitless_bottom_eltype(u))
     T2 = constvalue(typeof(one(t)))
     @OnDemandTableauExtract Vern7Tableau T T2
@@ -319,8 +319,8 @@ end
 end
 
 function initialize!(integrator, cache::Vern7Cache)
-    @unpack k1, k2, k3, k4, k5, k6, k7, k8, k9, k10 = cache
-    @unpack k = integrator
+    (; k1, k2, k3, k4, k5, k6, k7, k8, k9, k10) = cache
+    (; k) = integrator
     alg = unwrap_alg(integrator, false)
     cache.lazy ? (integrator.kshortsize = 10) : (integrator.kshortsize = 16)
     resize!(k, integrator.kshortsize)
@@ -346,11 +346,11 @@ function initialize!(integrator, cache::Vern7Cache)
 end
 
 @muladd function perform_step!(integrator, cache::Vern7Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     T = constvalue(recursive_unitless_bottom_eltype(u))
     T2 = constvalue(typeof(one(t)))
     @OnDemandTableauExtract Vern7Tableau T T2
-    @unpack k1, k2, k3, k4, k5, k6, k7, k8, k9, k10, utilde, tmp, rtmp, atmp, stage_limiter!, step_limiter!, thread = cache
+    (; k1, k2, k3, k4, k5, k6, k7, k8, k9, k10, utilde, tmp, rtmp, atmp, stage_limiter!, step_limiter!, thread) = cache
     f(k1, uprev, p, t)
     a = dt * a021
     @.. broadcast=false thread=thread tmp=uprev + a * k1
@@ -426,7 +426,7 @@ end
     if !cache.lazy && (integrator.opts.adaptive == false ||
         accept_step_controller(integrator, integrator.opts.controller))
         k = integrator.k
-        @unpack tmp = cache
+        (; tmp) = cache
         @OnDemandTableauExtract Vern7ExtraStages T T2
         @.. broadcast=false thread=thread tmp=uprev +
                                               dt *
@@ -489,8 +489,8 @@ function initialize!(integrator, cache::Vern8ConstantCache)
 end
 
 @muladd function perform_step!(integrator, cache::Vern8ConstantCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack c2, c3, c4, c5, c6, c7, c8, c9, c10, c11, a0201, a0301, a0302, a0401, a0403, a0501, a0503, a0504, a0601, a0604, a0605, a0701, a0704, a0705, a0706, a0801, a0804, a0805, a0806, a0807, a0901, a0904, a0905, a0906, a0907, a0908, a1001, a1004, a1005, a1006, a1007, a1008, a1009, a1101, a1104, a1105, a1106, a1107, a1108, a1109, a1110, a1201, a1204, a1205, a1206, a1207, a1208, a1209, a1210, a1211, a1301, a1304, a1305, a1306, a1307, a1308, a1309, a1310, b1, b6, b7, b8, b9, b10, b11, b12, btilde1, btilde6, btilde7, btilde8, btilde9, btilde10, btilde11, btilde12, btilde13 = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; c2, c3, c4, c5, c6, c7, c8, c9, c10, c11, a0201, a0301, a0302, a0401, a0403, a0501, a0503, a0504, a0601, a0604, a0605, a0701, a0704, a0705, a0706, a0801, a0804, a0805, a0806, a0807, a0901, a0904, a0905, a0906, a0907, a0908, a1001, a1004, a1005, a1006, a1007, a1008, a1009, a1101, a1104, a1105, a1106, a1107, a1108, a1109, a1110, a1201, a1204, a1205, a1206, a1207, a1208, a1209, a1210, a1211, a1301, a1304, a1305, a1306, a1307, a1308, a1309, a1310, b1, b6, b7, b8, b9, b10, b11, b12, btilde1, btilde6, btilde7, btilde8, btilde9, btilde10, btilde11, btilde12, btilde13) = cache.tab
     k1 = f(uprev, p, t)
     a = dt * a0201
     k2 = f(uprev + a * k1, p, t + c2 * dt)
@@ -567,7 +567,7 @@ end
     if !cache.lazy && (integrator.opts.adaptive == false ||
         accept_step_controller(integrator, integrator.opts.controller))
         k = integrator.k
-        @unpack c14, a1401, a1406, a1407, a1408, a1409, a1410, a1411, a1412, c15, a1501, a1506, a1507, a1508, a1509, a1510, a1511, a1512, a1514, c16, a1601, a1606, a1607, a1608, a1609, a1610, a1611, a1612, a1614, a1615, c17, a1701, a1706, a1707, a1708, a1709, a1710, a1711, a1712, a1714, a1715, a1716, c18, a1801, a1806, a1807, a1808, a1809, a1810, a1811, a1812, a1814, a1815, a1816, a1817, c19, a1901, a1906, a1907, a1908, a1909, a1910, a1911, a1912, a1914, a1915, a1916, a1917, c20, a2001, a2006, a2007, a2008, a2009, a2010, a2011, a2012, a2014, a2015, a2016, a2017, c21, a2101, a2106, a2107, a2108, a2109, a2110, a2111, a2112, a2114, a2115, a2116, a2117 = cache.tab.extra
+        (; c14, a1401, a1406, a1407, a1408, a1409, a1410, a1411, a1412, c15, a1501, a1506, a1507, a1508, a1509, a1510, a1511, a1512, a1514, c16, a1601, a1606, a1607, a1608, a1609, a1610, a1611, a1612, a1614, a1615, c17, a1701, a1706, a1707, a1708, a1709, a1710, a1711, a1712, a1714, a1715, a1716, c18, a1801, a1806, a1807, a1808, a1809, a1810, a1811, a1812, a1814, a1815, a1816, a1817, c19, a1901, a1906, a1907, a1908, a1909, a1910, a1911, a1912, a1914, a1915, a1916, a1917, c20, a2001, a2006, a2007, a2008, a2009, a2010, a2011, a2012, a2014, a2015, a2016, a2017, c21, a2101, a2106, a2107, a2108, a2109, a2110, a2111, a2112, a2114, a2115, a2116, a2117) = cache.tab.extra
         k[14] = f(
             uprev +
             dt * (a1401 * k[1] + a1406 * k[6] + a1407 * k[7] + a1408 * k[8] +
@@ -628,8 +628,8 @@ end
 end
 
 function initialize!(integrator, cache::Vern8Cache)
-    @unpack k1, k2, k3, k4, k5, k6, k7, k8, k9, k10, k11, k12, k13 = cache
-    @unpack k = integrator
+    (; k1, k2, k3, k4, k5, k6, k7, k8, k9, k10, k11, k12, k13) = cache
+    (; k) = integrator
     alg = unwrap_alg(integrator, false)
     cache.lazy ? (integrator.kshortsize = 13) : (integrator.kshortsize = 21)
     resize!(k, integrator.kshortsize)
@@ -655,10 +655,10 @@ function initialize!(integrator, cache::Vern8Cache)
 end
 
 @muladd function perform_step!(integrator, cache::Vern8Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     uidx = eachindex(integrator.uprev)
-    @unpack c2, c3, c4, c5, c6, c7, c8, c9, c10, c11, a0201, a0301, a0302, a0401, a0403, a0501, a0503, a0504, a0601, a0604, a0605, a0701, a0704, a0705, a0706, a0801, a0804, a0805, a0806, a0807, a0901, a0904, a0905, a0906, a0907, a0908, a1001, a1004, a1005, a1006, a1007, a1008, a1009, a1101, a1104, a1105, a1106, a1107, a1108, a1109, a1110, a1201, a1204, a1205, a1206, a1207, a1208, a1209, a1210, a1211, a1301, a1304, a1305, a1306, a1307, a1308, a1309, a1310, b1, b6, b7, b8, b9, b10, b11, b12, btilde1, btilde6, btilde7, btilde8, btilde9, btilde10, btilde11, btilde12, btilde13 = cache.tab
-    @unpack k1, k2, k3, k4, k5, k6, k7, k8, k9, k10, k11, k12, k13, utilde, tmp, rtmp, atmp, stage_limiter!, step_limiter!, thread = cache
+    (; c2, c3, c4, c5, c6, c7, c8, c9, c10, c11, a0201, a0301, a0302, a0401, a0403, a0501, a0503, a0504, a0601, a0604, a0605, a0701, a0704, a0705, a0706, a0801, a0804, a0805, a0806, a0807, a0901, a0904, a0905, a0906, a0907, a0908, a1001, a1004, a1005, a1006, a1007, a1008, a1009, a1101, a1104, a1105, a1106, a1107, a1108, a1109, a1110, a1201, a1204, a1205, a1206, a1207, a1208, a1209, a1210, a1211, a1301, a1304, a1305, a1306, a1307, a1308, a1309, a1310, b1, b6, b7, b8, b9, b10, b11, b12, btilde1, btilde6, btilde7, btilde8, btilde9, btilde10, btilde11, btilde12, btilde13) = cache.tab
+    (; k1, k2, k3, k4, k5, k6, k7, k8, k9, k10, k11, k12, k13, utilde, tmp, rtmp, atmp, stage_limiter!, step_limiter!, thread) = cache
     f(k1, uprev, p, t)
     a = dt * a0201
     @.. broadcast=false thread=thread tmp=uprev + a * k1
@@ -753,8 +753,8 @@ end
     if !cache.lazy && (integrator.opts.adaptive == false ||
         accept_step_controller(integrator, integrator.opts.controller))
         k = integrator.k
-        @unpack c14, a1401, a1406, a1407, a1408, a1409, a1410, a1411, a1412, c15, a1501, a1506, a1507, a1508, a1509, a1510, a1511, a1512, a1514, c16, a1601, a1606, a1607, a1608, a1609, a1610, a1611, a1612, a1614, a1615, c17, a1701, a1706, a1707, a1708, a1709, a1710, a1711, a1712, a1714, a1715, a1716, c18, a1801, a1806, a1807, a1808, a1809, a1810, a1811, a1812, a1814, a1815, a1816, a1817, c19, a1901, a1906, a1907, a1908, a1909, a1910, a1911, a1912, a1914, a1915, a1916, a1917, c20, a2001, a2006, a2007, a2008, a2009, a2010, a2011, a2012, a2014, a2015, a2016, a2017, c21, a2101, a2106, a2107, a2108, a2109, a2110, a2111, a2112, a2114, a2115, a2116, a2117 = cache.tab.extra
-        @unpack tmp = cache
+        (; c14, a1401, a1406, a1407, a1408, a1409, a1410, a1411, a1412, c15, a1501, a1506, a1507, a1508, a1509, a1510, a1511, a1512, a1514, c16, a1601, a1606, a1607, a1608, a1609, a1610, a1611, a1612, a1614, a1615, c17, a1701, a1706, a1707, a1708, a1709, a1710, a1711, a1712, a1714, a1715, a1716, c18, a1801, a1806, a1807, a1808, a1809, a1810, a1811, a1812, a1814, a1815, a1816, a1817, c19, a1901, a1906, a1907, a1908, a1909, a1910, a1911, a1912, a1914, a1915, a1916, a1917, c20, a2001, a2006, a2007, a2008, a2009, a2010, a2011, a2012, a2014, a2015, a2016, a2017, c21, a2101, a2106, a2107, a2108, a2109, a2110, a2111, a2112, a2114, a2115, a2116, a2117) = cache.tab.extra
+        (; tmp) = cache
         @.. broadcast=false thread=thread tmp=uprev +
                                               dt *
                                               (a1401 * k[1] + a1406 * k[6] + a1407 * k[7] +
@@ -847,7 +847,7 @@ function initialize!(integrator, cache::Vern9ConstantCache)
 end
 
 @muladd function perform_step!(integrator, cache::Vern9ConstantCache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     T = constvalue(recursive_unitless_bottom_eltype(u))
     T2 = constvalue(typeof(one(t)))
     @OnDemandTableauExtract Vern9Tableau T T2
@@ -1014,8 +1014,8 @@ end
 end
 
 function initialize!(integrator, cache::Vern9Cache)
-    @unpack k1, k2, k3, k4, k5, k6, k7, k8, k9, k10, k11, k12, k13, k14, k15, k16 = cache
-    @unpack k = integrator
+    (; k1, k2, k3, k4, k5, k6, k7, k8, k9, k10, k11, k12, k13, k14, k15, k16) = cache
+    (; k) = integrator
     alg = unwrap_alg(integrator, false)
     cache.lazy ? (integrator.kshortsize = 10) : (integrator.kshortsize = 20)
     resize!(k, integrator.kshortsize)
@@ -1040,12 +1040,12 @@ function initialize!(integrator, cache::Vern9Cache)
 end
 
 @muladd function perform_step!(integrator, cache::Vern9Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     uidx = eachindex(integrator.uprev)
     T = constvalue(recursive_unitless_bottom_eltype(u))
     T2 = constvalue(typeof(one(t)))
     @OnDemandTableauExtract Vern9Tableau T T2
-    @unpack k1, k2, k3, k4, k5, k6, k7, k8, k9, k10, k11, k12, k13, k14, k15, k16, utilde, tmp, rtmp, atmp, stage_limiter!, step_limiter!, thread = cache
+    (; k1, k2, k3, k4, k5, k6, k7, k8, k9, k10, k11, k12, k13, k14, k15, k16, utilde, tmp, rtmp, atmp, stage_limiter!, step_limiter!, thread) = cache
     f(k1, uprev, p, t)
     a = dt * a0201
     @.. broadcast=false thread=thread tmp=uprev + a * k1
@@ -1159,7 +1159,7 @@ end
     if !cache.lazy && (integrator.opts.adaptive == false ||
         accept_step_controller(integrator, integrator.opts.controller))
         k = integrator.k
-        @unpack tmp = cache
+        (; tmp) = cache
         @OnDemandTableauExtract Vern9ExtraStages T T2
         @.. broadcast=false thread=thread tmp=uprev +
                                               dt *
@@ -1264,3 +1264,129 @@ end
     end
     return nothing
 end
+
+function initialize!(integrator, cache::RKV76IIaConstantCache)
+    integrator.fsalfirst = integrator.f(integrator.uprev, integrator.p, integrator.t) # Pre-start fsal
+    OrdinaryDiffEqCore.increment_nf!(integrator.stats, 1)
+    alg = unwrap_alg(integrator, false)
+    cache.lazy ? (integrator.kshortsize = 10) : (integrator.kshortsize = 10)
+    integrator.k = typeof(integrator.k)(undef, integrator.kshortsize)
+
+    # Avoid undefined entries if k is an array of arrays
+    integrator.fsallast = zero(integrator.fsalfirst)
+    integrator.k[1] = zero(integrator.fsalfirst)
+    @inbounds for i in 2:integrator.kshortsize-1
+        integrator.k[i] = zero(integrator.fsalfirst)
+    end
+    integrator.k[integrator.kshortsize] = zero(integrator.fsallast)
+end
+
+@muladd function perform_step!(integrator, cache::RKV76IIaConstantCache, repeat_step = false)
+    (; t, dt, uprev, u, f, p) = integrator
+    (; c1, c2, c3, c4, c5, c6, c7, c8, c9, c10, 
+            a21, a31, a32, a41, a42, a43, a51, a52, a53, a54,
+            a61, a62, a63, a64, a65, a71, a72, a73, a74, a75, a76,
+            a81, a82, a83, a84, a85, a86, a87,
+            a91, a92, a93, a94, a95, a96, a97, a98,
+            a101, a102, a103, a104, a105, a106, a107, a108, a109,
+            b1, b2, b3, b4, b5, b6, b7, b8, b9, b10,
+            bh1, bh2, bh3, bh4, bh5, bh6, bh7, bh8, bh9, bh10) = cache.tab
+
+    k1 = f(uprev, p, t)
+    k2 = f(uprev + dt * a21 * k1, p, t + c2 * dt)
+    k3 = f(uprev + dt * (a31 * k1 + a32 * k2), p, t + c3 * dt)
+    k4 = f(uprev + dt * (a41 * k1 + a42 * k2 + a43 * k3), p, t + c4 * dt)
+    k5 = f(uprev + dt * (a51 * k1 + a52 * k2 + a53 * k3 + a54 * k4), p, t + c5 * dt)
+    k6 = f(uprev + dt * (a61 * k1 + a62 * k2 + a63 * k3 + a64 * k4 + a65 * k5), p, t + c6 * dt)
+    k7 = f(uprev + dt * (a71 * k1 + a72 * k2 + a73 * k3 + a74 * k4 + a75 * k5 + a76 * k6), p, t + c7 * dt)
+    k8 = f(uprev + dt * (a81 * k1 + a82 * k2 + a83 * k3 + a84 * k4 + a85 * k5 + a86 * k6 + a87 * k7), p, t + c8 * dt)
+    k9 = f(uprev + dt * (a91 * k1 + a92 * k2 + a93 * k3 + a94 * k4 + a95 * k5 + a96 * k6 + a97 * k7 + a98 * k8), p, t + c9 * dt)
+    k10 = f(uprev + dt * (a101 * k1 + a102 * k2 + a103 * k3 + a104 * k4 + a105 * k5 + a106 * k6 + a107 * k7 + a108 * k8 + a109 * k9), p, t + c10 * dt)
+
+    u = uprev + dt * (b1 * k1 + b2 * k2 + b3 * k3 + b4 * k4 + b5 * k5 + b6 * k6 + b7 * k7 + b8 * k8 + b9 * k9 + b10 * k10)
+
+    OrdinaryDiffEqCore.increment_nf!(integrator.stats, 10)
+
+    if integrator.opts.adaptive
+        uhat = uprev + dt * (bh1 * k1 + bh2 * k2 + bh3 * k3 + bh4 * k4 + bh5 * k5 + bh6 * k6 + bh7 * k7 + bh8 * k8 + bh9 * k9 + bh10 * k10)
+        atmp = calculate_residuals(u .- uhat, uprev, u, integrator.opts.abstol,
+            integrator.opts.reltol, integrator.opts.internalnorm, t)
+        integrator.EEst = integrator.opts.internalnorm(atmp, t)
+    end
+
+    integrator.k[1] = k1
+    integrator.k[2] = k2
+    integrator.k[3] = k3
+    integrator.k[4] = k4
+    integrator.k[5] = k5
+    integrator.k[6] = k6
+    integrator.k[7] = k7
+    integrator.k[8] = k8
+    integrator.k[9] = k9
+    integrator.k[10] = k10
+
+    integrator.u = u
+end
+
+function initialize!(integrator, cache::RKV76IIaCache)
+    alg = unwrap_alg(integrator, false)
+    cache.lazy ? (integrator.kshortsize = 10) : (integrator.kshortsize = 10)
+    (; k) = integrator
+    resize!(k, integrator.kshortsize)
+    k[1] = cache.k1
+    k[2] = cache.k2
+    k[3] = cache.k3
+    k[4] = cache.k4
+    k[5] = cache.k5
+    k[6] = cache.k6
+    k[7] = cache.k7
+    k[8] = cache.k8
+    k[9] = cache.k9
+    k[10] = cache.k10
+end
+
+@muladd function perform_step!(integrator, cache::RKV76IIaCache, repeat_step = false)
+    (; t, dt, uprev, u, f, p) = integrator
+    (; c1, c2, c3, c4, c5, c6, c7, c8, c9, c10, 
+            a21, a31, a32, a41, a42, a43, a51, a52, a53, a54,
+            a61, a62, a63, a64, a65, a71, a72, a73, a74, a75, a76,
+            a81, a82, a83, a84, a85, a86, a87,
+            a91, a92, a93, a94, a95, a96, a97, a98,
+            a101, a102, a103, a104, a105, a106, a107, a108, a109,
+            b1, b2, b3, b4, b5, b6, b7, b8, b9, b10,
+            bh1, bh2, bh3, bh4, bh5, bh6, bh7, bh8, bh9, bh10) = cache.tab
+    (; k1, k2, k3, k4, k5, k6, k7, k8, k9, k10, utilde, tmp, atmp) = cache
+    (; thread) = cache
+
+    f(k1, uprev, p, t)
+    @.. broadcast=false thread=thread tmp = uprev + dt * a21 * k1
+    f(k2, tmp, p, t + c2 * dt)
+    @.. broadcast=false thread=thread tmp = uprev + dt * (a31 * k1 + a32 * k2)
+    f(k3, tmp, p, t + c3 * dt)
+    @.. broadcast=false thread=thread tmp = uprev + dt * (a41 * k1 + a42 * k2 + a43 * k3)
+    f(k4, tmp, p, t + c4 * dt)
+    @.. broadcast=false thread=thread tmp = uprev + dt * (a51 * k1 + a52 * k2 + a53 * k3 + a54 * k4)
+    f(k5, tmp, p, t + c5 * dt)
+    @.. broadcast=false thread=thread tmp = uprev + dt * (a61 * k1 + a62 * k2 + a63 * k3 + a64 * k4 + a65 * k5)
+    f(k6, tmp, p, t + c6 * dt)
+    @.. broadcast=false thread=thread tmp = uprev + dt * (a71 * k1 + a72 * k2 + a73 * k3 + a74 * k4 + a75 * k5 + a76 * k6)
+    f(k7, tmp, p, t + c7 * dt)
+    @.. broadcast=false thread=thread tmp = uprev + dt * (a81 * k1 + a82 * k2 + a83 * k3 + a84 * k4 + a85 * k5 + a86 * k6 + a87 * k7)
+    f(k8, tmp, p, t + c8 * dt)
+    @.. broadcast=false thread=thread tmp = uprev + dt * (a91 * k1 + a92 * k2 + a93 * k3 + a94 * k4 + a95 * k5 + a96 * k6 + a97 * k7 + a98 * k8)
+    f(k9, tmp, p, t + c9 * dt)
+    @.. broadcast=false thread=thread tmp = uprev + dt * (a101 * k1 + a102 * k2 + a103 * k3 + a104 * k4 + a105 * k5 + a106 * k6 + a107 * k7 + a108 * k8 + a109 * k9)
+    f(k10, tmp, p, t + c10 * dt)
+
+    @.. broadcast=false thread=thread u = uprev + dt * (b1 * k1 + b2 * k2 + b3 * k3 + b4 * k4 + b5 * k5 + b6 * k6 + b7 * k7 + b8 * k8 + b9 * k9 + b10 * k10)
+
+    OrdinaryDiffEqCore.increment_nf!(integrator.stats, 10)
+
+    if integrator.opts.adaptive
+        @.. broadcast=false thread=thread utilde = uprev + dt * (bh1 * k1 + bh2 * k2 + bh3 * k3 + bh4 * k4 + bh5 * k5 + bh6 * k6 + bh7 * k7 + bh8 * k8 + bh9 * k9 + bh10 * k10)
+        @.. broadcast=false thread=thread atmp = u - utilde
+        calculate_residuals!(atmp, atmp, uprev, u, integrator.opts.abstol,
+            integrator.opts.reltol, integrator.opts.internalnorm, t, thread)
+        integrator.EEst = integrator.opts.internalnorm(atmp, t)
+    end
+end
